# Contributing

**Find this project useful?** Help us make it even better by submitting any bugs or improvement
suggestions you have as GitHub Issues and Pull Requests.


## Pull Requests

This project uses [git-flow](https://github.com/nvie/gitflow).

Please submit PRs against the `develop` branch.
